@@ -1,12 +1,16 @@
+use strict;
+use warnings;
 package MooseX::Daemonize::Pid::File;
-use strict;    # because Kwalitee is pedantic
-use Moose;
-use Moose::Util::TypeConstraints;
+# ABSTRACT: PID file management for MooseX::Daemonize
 
-our $VERSION   = '0.15';
+our $VERSION = '0.20';
+
+use Moose;
+use Moose::Util::TypeConstraints qw(coerce from via);
 
 use MooseX::Types::Path::Class;
 use MooseX::Getopt::OptionTypeMap;
+use namespace::autoclean;
 
 # NOTE:
 # set up some basic coercions
@@ -67,10 +71,16 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 MooseX::Daemonize::Pid::File - PID file management for MooseX::Daemonize
 
+=head1 VERSION
+
+version 0.20
+
 =head1 DESCRIPTION
 
 This object extends L<MooseX::Daemonize::Pid> to add persistence in a Pidfile.
@@ -134,52 +144,31 @@ The C<meta()> method from L<Class::MOP::Class>
 
 Obviously L<Moose>
 
-=head1 INCOMPATIBILITIES
-
-None reported.
-
 =head1 BUGS AND LIMITATIONS
 
-No bugs have been reported.
-
 Please report any bugs or feature requests to
-C<bug-acme-dahut-call@rt.cpan.org>, or through the web interface at
+C<bug-MooseX-Daemonize@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Stevan Little  C<< <stevan.little@iinteractive.com> >>
+=over 4
 
-=head1 LICENCE AND COPYRIGHT
+=item *
 
-Copyright (c) 2007-2011, Chris Prather C<< <perigrin@cpan.org> >>. All rights
-reserved.
+Stevan Little <stevan.little@iinteractive.com>
 
-This module is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself. See L<perlartistic>.
+=item *
 
+Chris Prather <chris@prather.org>
 
-=head1 DISCLAIMER OF WARRANTY
+=back
 
-BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
-FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
-OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
-PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
-EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
-ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
-YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
-NECESSARY SERVICING, REPAIR, OR CORRECTION.
+=head1 COPYRIGHT AND LICENCE
 
-IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
-WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
-REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE
-LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
-OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
-THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
-RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
-FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
-SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
-SUCH DAMAGES.
+This software is copyright (c) 2007 by Chris Prather.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
